@@ -474,7 +474,7 @@ class FileMuncher:
         dir_to_create = self._convert_path_type(dir_to_create)  # normalize the path
         dir_to_create.mkdir(parents=True, exist_ok=True)        # create the directory
 
-    def create_new_file(self, file_to_create: 'Path') -> None:
+    def create_new_file(self, file_to_create: Union['Path', str]) -> None:
         """
         Create a new file.
 
